<?php

return [
    'Names' => [
        'aa' => 'Afar',
        'ab' => 'Abchasisch',
        'ace' => 'Aceh',
        'ach' => 'Acholi',
        'ada' => 'Adangme',
        'ady' => 'Adygeisch',
        'ae' => 'Avestisch',
        'aeb' => 'Tunesisches Arabisch',
        'af' => 'Afrikaans',
        'afh' => 'Afrihili',
        'agq' => 'Aghem',
        'ain' => 'Ainu',
        'ak' => 'Akan',
        'akk' => 'Akkadisch',
        'akz' => 'Alabama',
        'ale' => 'Aleutisch',
        'aln' => 'Gegisch',
        'alt' => 'Süd-Altaisch',
        'am' => 'Amharisch',
        'an' => 'Aragonesisch',
        'ang' => 'Altenglisch',
        'ann' => 'Obolo',
        'anp' => 'Angika',
        'ar' => 'Arabisch',
        'arc' => 'Aramäisch',
        'arn' => 'Mapudungun',
        'aro' => 'Araona',
        'arp' => 'Arapaho',
        'arq' => 'Algerisches Arabisch',
        'ars' => 'Arabisch (Nadschd)',
        'arw' => 'Arawak',
        'ary' => 'Marokkanisches Arabisch',
        'arz' => 'Ägyptisches Arabisch',
        'as' => 'Assamesisch',
        'asa' => 'Asu',
        'ase' => 'Amerikanische Gebärdensprache',
        'ast' => 'Asturisch',
        'atj' => 'Atikamekw',
        'av' => 'Awarisch',
        'avk' => 'Kotava',
        'awa' => 'Awadhi',
        'ay' => 'Aymara',
        'az' => 'Aserbaidschanisch',
        'ba' => 'Baschkirisch',
        'bal' => 'Belutschisch',
        'ban' => 'Balinesisch',
        'bar' => 'Bairisch',
        'bas' => 'Bassa',
        'bax' => 'Bamun',
        'bbc' => 'Batak Toba',
        'bbj' => 'Ghomala',
        'be' => 'Belarussisch',
        'bej' => 'Bedauye',
        'bem' => 'Bemba',
        'bew' => 'Betawi',
        'bez' => 'Bena',
        'bfd' => 'Bafut',
        'bfq' => 'Badaga',
        'bg' => 'Bulgarisch',
        'bgn' => 'Westliches Belutschi',
        'bho' => 'Bhodschpuri',
        'bi' => 'Bislama',
        'bik' => 'Bikol',
        'bin' => 'Bini',
        'bjn' => 'Banjaresisch',
        'bkm' => 'Kom',
        'bla' => 'Blackfoot',
        'bm' => 'Bambara',
        'bn' => 'Bengalisch',
        'bo' => 'Tibetisch',
        'bpy' => 'Bishnupriya',
        'bqi' => 'Bachtiarisch',
        'br' => 'Bretonisch',
        'bra' => 'Braj-Bhakha',
        'brh' => 'Brahui',
        'brx' => 'Bodo',
        'bs' => 'Bosnisch',
        'bss' => 'Akoose',
        'bua' => 'Burjatisch',
        'bug' => 'Buginesisch',
        'bum' => 'Bulu',
        'byn' => 'Blin',
        'byv' => 'Medumba',
        'ca' => 'Katalanisch',
        'cad' => 'Caddo',
        'car' => 'Karibisch',
        'cay' => 'Cayuga',
        'cch' => 'Atsam',
        'ccp' => 'Chakma',
        'ce' => 'Tschetschenisch',
        'ceb' => 'Cebuano',
        'cgg' => 'Rukiga',
        'ch' => 'Chamorro',
        'chb' => 'Chibcha',
        'chg' => 'Tschagataisch',
        'chk' => 'Chuukesisch',
        'chm' => 'Mari',
        'chn' => 'Chinook',
        'cho' => 'Choctaw',
        'chp' => 'Chipewyan',
        'chr' => 'Cherokee',
        'chy' => 'Cheyenne',
        'ckb' => 'Zentralkurdisch',
        'clc' => 'Chilcotin',
        'co' => 'Korsisch',
        'cop' => 'Koptisch',
        'cps' => 'Capiznon',
        'cr' => 'Cree',
        'crg' => 'Michif',
        'crh' => 'Krimtatarisch',
        'crj' => 'Südost-Cree',
        'crk' => 'Plains-Cree',
        'crl' => 'Northern East Cree',
        'crm' => 'Moose Cree',
        'crr' => 'Carolina-Algonkin',
        'crs' => 'Seychellenkreol',
        'cs' => 'Tschechisch',
        'csb' => 'Kaschubisch',
        'csw' => 'Swampy Cree',
        'cu' => 'Kirchenslawisch',
        'cv' => 'Tschuwaschisch',
        'cy' => 'Walisisch',
        'da' => 'Dänisch',
        'dak' => 'Dakota',
        'dar' => 'Darginisch',
        'dav' => 'Taita',
        'de' => 'Deutsch',
        'del' => 'Delaware',
        'den' => 'Slave',
        'dgr' => 'Dogrib',
        'din' => 'Dinka',
        'dje' => 'Zarma',
        'doi' => 'Dogri',
        'dsb' => 'Niedersorbisch',
        'dtp' => 'Zentral-Dusun',
        'dua' => 'Duala',
        'dum' => 'Mittelniederländisch',
        'dv' => 'Dhivehi',
        'dyo' => 'Diola',
        'dyu' => 'Dyula',
        'dz' => 'Dzongkha',
        'dzg' => 'Dazaga',
        'ebu' => 'Embu',
        'ee' => 'Ewe',
        'efi' => 'Efik',
        'egl' => 'Emilianisch',
        'egy' => 'Ägyptisch',
        'eka' => 'Ekajuk',
        'el' => 'Griechisch',
        'elx' => 'Elamisch',
        'en' => 'Englisch',
        'enm' => 'Mittelenglisch',
        'eo' => 'Esperanto',
        'es' => 'Spanisch',
        'esu' => 'Zentral-Alaska-Yupik',
        'et' => 'Estnisch',
        'eu' => 'Baskisch',
        'ewo' => 'Ewondo',
        'ext' => 'Extremadurisch',
        'fa' => 'Persisch',
        'fan' => 'Pangwe',
        'fat' => 'Fanti',
        'ff' => 'Ful',
        'fi' => 'Finnisch',
        'fil' => 'Filipino',
        'fit' => 'Meänkieli',
        'fj' => 'Fidschi',
        'fo' => 'Färöisch',
        'fon' => 'Fon',
        'fr' => 'Französisch',
        'frc' => 'Cajun',
        'frm' => 'Mittelfranzösisch',
        'fro' => 'Altfranzösisch',
        'frp' => 'Frankoprovenzalisch',
        'frr' => 'Nordfriesisch',
        'frs' => 'Ostfriesisch',
        'fur' => 'Friaulisch',
        'fy' => 'Westfriesisch',
        'ga' => 'Irisch',
        'gaa' => 'Ga',
        'gag' => 'Gagausisch',
        'gan' => 'Gan',
        'gay' => 'Gayo',
        'gba' => 'Gbaya',
        'gbz' => 'Gabri',
        'gd' => 'Gälisch (Schottland)',
        'gez' => 'Geez',
        'gil' => 'Kiribatisch',
        'gl' => 'Galicisch',
        'glk' => 'Gilaki',
        'gmh' => 'Mittelhochdeutsch',
        'gn' => 'Guaraní',
        'goh' => 'Althochdeutsch',
        'gom' => 'Goa-Konkani',
        'gon' => 'Gondi',
        'gor' => 'Mongondou',
        'got' => 'Gotisch',
        'grb' => 'Grebo',
        'grc' => 'Altgriechisch',
        'gsw' => 'Schweizerdeutsch',
        'gu' => 'Gujarati',
        'guc' => 'Wayúu',
        'gur' => 'Farefare',
        'guz' => 'Gusii',
        'gv' => 'Manx',
        'gwi' => 'Kutchin',
        'ha' => 'Haussa',
        'hai' => 'Haida',
        'hak' => 'Hakka',
        'haw' => 'Hawaiisch',
        'hax' => 'Süd-Haida',
        'he' => 'Hebräisch',
        'hi' => 'Hindi',
        'hif' => 'Fidschi-Hindi',
        'hil' => 'Hiligaynon',
        'hit' => 'Hethitisch',
        'hmn' => 'Miao',
        'ho' => 'Hiri-Motu',
        'hr' => 'Kroatisch',
        'hsb' => 'Obersorbisch',
        'hsn' => 'Xiang',
        'ht' => 'Haiti-Kreolisch',
        'hu' => 'Ungarisch',
        'hup' => 'Hupa',
        'hur' => 'Halkomelem',
        'hy' => 'Armenisch',
        'hz' => 'Herero',
        'ia' => 'Interlingua',
        'iba' => 'Iban',
        'ibb' => 'Ibibio',
        'id' => 'Indonesisch',
        'ie' => 'Interlingue',
        'ig' => 'Igbo',
        'ii' => 'Yi',
        'ik' => 'Inupiak',
        'ikt' => 'Westkanadisches Inuktitut',
        'ilo' => 'Ilokano',
        'inh' => 'Inguschisch',
        'io' => 'Ido',
        'is' => 'Isländisch',
        'it' => 'Italienisch',
        'iu' => 'Inuktitut',
        'izh' => 'Ischorisch',
        'ja' => 'Japanisch',
        'jam' => 'Jamaikanisch-Kreolisch',
        'jbo' => 'Lojban',
        'jgo' => 'Ngomba',
        'jmc' => 'Machame',
        'jpr' => 'Jüdisch-Persisch',
        'jrb' => 'Jüdisch-Arabisch',
        'jut' => 'Jütisch',
        'jv' => 'Javanisch',
        'ka' => 'Georgisch',
        'kaa' => 'Karakalpakisch',
        'kab' => 'Kabylisch',
        'kac' => 'Kachin',
        'kaj' => 'Jju',
        'kam' => 'Kamba',
        'kaw' => 'Kawi',
        'kbd' => 'Kabardinisch',
        'kbl' => 'Kanembu',
        'kcg' => 'Tyap',
        'kde' => 'Makonde',
        'kea' => 'Kabuverdianu',
        'ken' => 'Kenyang',
        'kfo' => 'Koro',
        'kg' => 'Kongolesisch',
        'kgp' => 'Kaingang',
        'kha' => 'Khasi',
        'kho' => 'Sakisch',
        'khq' => 'Koyra Chiini',
        'khw' => 'Khowar',
        'ki' => 'Kikuyu',
        'kiu' => 'Kirmanjki',
        'kj' => 'Kwanyama',
        'kk' => 'Kasachisch',
        'kkj' => 'Kako',
        'kl' => 'Grönländisch',
        'kln' => 'Kalenjin',
        'km' => 'Khmer',
        'kmb' => 'Kimbundu',
        'kn' => 'Kannada',
        'ko' => 'Koreanisch',
        'koi' => 'Komi-Permjakisch',
        'kok' => 'Konkani',
        'kos' => 'Kosraeanisch',
        'kpe' => 'Kpelle',
        'kr' => 'Kanuri',
        'krc' => 'Karatschaiisch-Balkarisch',
        'kri' => 'Krio',
        'krj' => 'Kinaray-a',
        'krl' => 'Karelisch',
        'kru' => 'Oraon',
        'ks' => 'Kaschmiri',
        'ksb' => 'Shambala',
        'ksf' => 'Bafia',
        'ksh' => 'Kölsch',
        'ku' => 'Kurdisch',
        'kum' => 'Kumükisch',
        'kut' => 'Kutenai',
        'kv' => 'Komi',
        'kw' => 'Kornisch',
        'kwk' => 'Kwakʼwala',
        'ky' => 'Kirgisisch',
        'la' => 'Latein',
        'lad' => 'Ladino',
        'lag' => 'Langi',
        'lah' => 'Lahnda',
        'lam' => 'Lamba',
        'lb' => 'Luxemburgisch',
        'lez' => 'Lesgisch',
        'lfn' => 'Lingua Franca Nova',
        'lg' => 'Ganda',
        'li' => 'Limburgisch',
        'lij' => 'Ligurisch',
        'lil' => 'Lillooet',
        'liv' => 'Livisch',
        'lkt' => 'Lakota',
        'lmo' => 'Lombardisch',
        'ln' => 'Lingala',
        'lo' => 'Laotisch',
        'lol' => 'Mongo',
        'lou' => 'Kreol (Louisiana)',
        'loz' => 'Lozi',
        'lrc' => 'Nördliches Luri',
        'lsm' => 'Saamia',
        'lt' => 'Litauisch',
        'ltg' => 'Lettgallisch',
        'lu' => 'Luba-Katanga',
        'lua' => 'Luba-Lulua',
        'lui' => 'Luiseno',
        'lun' => 'Lunda',
        'luo' => 'Luo',
        'lus' => 'Lushai',
        'luy' => 'Luhya',
        'lv' => 'Lettisch',
        'lzh' => 'Klassisches Chinesisch',
        'lzz' => 'Lasisch',
        'mad' => 'Maduresisch',
        'maf' => 'Mafa',
        'mag' => 'Khotta',
        'mai' => 'Maithili',
        'mak' => 'Makassarisch',
        'man' => 'Malinke',
        'mas' => 'Massai',
        'mde' => 'Maba',
        'mdf' => 'Mokschanisch',
        'mdr' => 'Mandaresisch',
        'men' => 'Mende',
        'mer' => 'Meru',
        'mfe' => 'Morisyen',
        'mg' => 'Malagasy',
        'mga' => 'Mittelirisch',
        'mgh' => 'Makhuwa-Meetto',
        'mgo' => 'Meta’',
        'mh' => 'Marschallesisch',
        'mi' => 'Māori',
        'mic' => 'Micmac',
        'min' => 'Minangkabau',
        'mk' => 'Mazedonisch',
        'ml' => 'Malayalam',
        'mn' => 'Mongolisch',
        'mnc' => 'Mandschurisch',
        'mni' => 'Meithei',
        'moe' => 'Innu-Aimun',
        'moh' => 'Mohawk',
        'mos' => 'Mossi',
        'mr' => 'Marathi',
        'mrj' => 'Bergmari',
        'ms' => 'Malaiisch',
        'mt' => 'Maltesisch',
        'mua' => 'Mundang',
        'mus' => 'Muskogee',
        'mwl' => 'Mirandesisch',
        'mwr' => 'Marwari',
        'mwv' => 'Mentawai',
        'my' => 'Birmanisch',
        'mye' => 'Myene',
        'myv' => 'Ersja-Mordwinisch',
        'mzn' => 'Masanderanisch',
        'na' => 'Nauruisch',
        'nan' => 'Min Nan',
        'nap' => 'Neapolitanisch',
        'naq' => 'Nama',
        'nb' => 'Norwegisch (Bokmål)',
        'nd' => 'Nord-Ndebele',
        'nds' => 'Niederdeutsch',
        'ne' => 'Nepalesisch',
        'new' => 'Newari',
        'ng' => 'Ndonga',
        'nia' => 'Nias',
        'niu' => 'Niue',
        'njo' => 'Ao-Naga',
        'nl' => 'Niederländisch',
        'nmg' => 'Kwasio',
        'nn' => 'Norwegisch (Nynorsk)',
        'nnh' => 'Ngiemboon',
        'no' => 'Norwegisch',
        'nog' => 'Nogai',
        'non' => 'Altnordisch',
        'nov' => 'Novial',
        'nqo' => 'N’Ko',
        'nr' => 'Süd-Ndebele',
        'nso' => 'Nord-Sotho',
        'nus' => 'Nuer',
        'nv' => 'Navajo',
        'nwc' => 'Alt-Newari',
        'ny' => 'Nyanja',
        'nym' => 'Nyamwezi',
        'nyn' => 'Nyankole',
        'nyo' => 'Nyoro',
        'nzi' => 'Nzima',
        'oc' => 'Okzitanisch',
        'oj' => 'Ojibwa',
        'ojb' => 'Nordwest-Ojibwe',
        'ojc' => 'Zentral-Ojibwe',
        'ojs' => 'Oji-Cree',
        'ojw' => 'West-Ojibwe',
        'oka' => 'Okanagan',
        'om' => 'Oromo',
        'or' => 'Oriya',
        'os' => 'Ossetisch',
        'osa' => 'Osage',
        'ota' => 'Osmanisch',
        'pa' => 'Punjabi',
        'pag' => 'Pangasinan',
        'pal' => 'Mittelpersisch',
        'pam' => 'Pampanggan',
        'pap' => 'Papiamento',
        'pau' => 'Palau',
        'pcd' => 'Picardisch',
        'pcm' => 'Nigerianisches Pidgin',
        'pdc' => 'Pennsylvaniadeutsch',
        'pdt' => 'Plautdietsch',
        'peo' => 'Altpersisch',
        'pfl' => 'Pfälzisch',
        'phn' => 'Phönizisch',
        'pi' => 'Pali',
        'pis' => 'Pijin',
        'pl' => 'Polnisch',
        'pms' => 'Piemontesisch',
        'pnt' => 'Pontisch',
        'pon' => 'Ponapeanisch',
        'pqm' => 'Maliseet-Passamaquoddy',
        'prg' => 'Altpreußisch',
        'pro' => 'Altprovenzalisch',
        'ps' => 'Paschtu',
        'pt' => 'Portugiesisch',
        'qu' => 'Quechua',
        'quc' => 'K’iche’',
        'qug' => 'Chimborazo Hochland-Quechua',
        'raj' => 'Rajasthani',
        'rap' => 'Rapanui',
        'rar' => 'Rarotonganisch',
        'rgn' => 'Romagnol',
        'rhg' => 'Rohingyalisch',
        'rif' => 'Tarifit',
        'rm' => 'Rätoromanisch',
        'rn' => 'Rundi',
        'ro' => 'Rumänisch',
        'rof' => 'Rombo',
        'rom' => 'Romani',
        'rtm' => 'Rotumanisch',
        'ru' => 'Russisch',
        'rue' => 'Russinisch',
        'rug' => 'Roviana',
        'rup' => 'Aromunisch',
        'rw' => 'Kinyarwanda',
        'rwk' => 'Rwa',
        'sa' => 'Sanskrit',
        'sad' => 'Sandawe',
        'sah' => 'Jakutisch',
        'sam' => 'Samaritanisch',
        'saq' => 'Samburu',
        'sas' => 'Sasak',
        'sat' => 'Santali',
        'saz' => 'Saurashtra',
        'sba' => 'Ngambay',
        'sbp' => 'Sangu',
        'sc' => 'Sardisch',
        'scn' => 'Sizilianisch',
        'sco' => 'Schottisch',
        'sd' => 'Sindhi',
        'sdc' => 'Sassarisch',
        'sdh' => 'Südkurdisch',
        'se' => 'Nordsamisch',
        'see' => 'Seneca',
        'seh' => 'Sena',
        'sei' => 'Seri',
        'sel' => 'Selkupisch',
        'ses' => 'Koyra Senni',
        'sg' => 'Sango',
        'sga' => 'Altirisch',
        'sgs' => 'Samogitisch',
        'sh' => 'Serbo-Kroatisch',
        'shi' => 'Taschelhit',
        'shn' => 'Schan',
        'shu' => 'Tschadisch-Arabisch',
        'si' => 'Singhalesisch',
        'sid' => 'Sidamo',
        'sk' => 'Slowakisch',
        'sl' => 'Slowenisch',
        'slh' => 'Süd-Lushootseed',
        'sli' => 'Schlesisch (Niederschlesisch)',
        'sly' => 'Selayar',
        'sm' => 'Samoanisch',
        'sma' => 'Südsamisch',
        'smj' => 'Lule-Samisch',
        'smn' => 'Inari-Samisch',
        'sms' => 'Skolt-Samisch',
        'sn' => 'Shona',
        'snk' => 'Soninke',
        'so' => 'Somali',
        'sog' => 'Sogdisch',
        'sq' => 'Albanisch',
        'sr' => 'Serbisch',
        'srn' => 'Srananisch',
        'srr' => 'Serer',
        'ss' => 'Swazi',
        'ssy' => 'Saho',
        'st' => 'Süd-Sotho',
        'stq' => 'Saterfriesisch',
        'str' => 'Straits Salish',
        'su' => 'Sundanesisch',
        'suk' => 'Sukuma',
        'sus' => 'Susu',
        'sux' => 'Sumerisch',
        'sv' => 'Schwedisch',
        'sw' => 'Suaheli',
        'swb' => 'Komorisch',
        'syc' => 'Altsyrisch',
        'syr' => 'Syrisch',
        'szl' => 'Schlesisch (Wasserpolnisch)',
        'ta' => 'Tamil',
        'tce' => 'Südliches Tutchone',
        'tcy' => 'Tulu',
        'te' => 'Telugu',
        'tem' => 'Temne',
        'teo' => 'Teso',
        'ter' => 'Tereno',
        'tet' => 'Tetum',
        'tg' => 'Tadschikisch',
        'tgx' => 'Tagish',
        'th' => 'Thailändisch',
        'tht' => 'Tahltan',
        'ti' => 'Tigrinya',
        'tig' => 'Tigre',
        'tiv' => 'Tiv',
        'tk' => 'Turkmenisch',
        'tkl' => 'Tokelauanisch',
        'tkr' => 'Tsachurisch',
        'tl' => 'Tagalog',
        'tlh' => 'Klingonisch',
        'tli' => 'Tlingit',
        'tly' => 'Talisch',
        'tmh' => 'Tamaseq',
        'tn' => 'Tswana',
        'to' => 'Tongaisch',
        'tog' => 'Nyasa Tonga',
        'tok' => 'Toki Pona',
        'tpi' => 'Neumelanesisch',
        'tr' => 'Türkisch',
        'tru' => 'Turoyo',
        'trv' => 'Taroko',
        'ts' => 'Tsonga',
        'tsd' => 'Tsakonisch',
        'tsi' => 'Tsimshian',
        'tt' => 'Tatarisch',
        'ttm' => 'Nördliches Tutchone',
        'ttt' => 'Tatisch',
        'tum' => 'Tumbuka',
        'tvl' => 'Tuvaluisch',
        'tw' => 'Twi',
        'twq' => 'Tasawaq',
        'ty' => 'Tahitisch',
        'tyv' => 'Tuwinisch',
        'tzm' => 'Zentralatlas-Tamazight',
        'udm' => 'Udmurtisch',
        'ug' => 'Uigurisch',
        'uga' => 'Ugaritisch',
        'uk' => 'Ukrainisch',
        'umb' => 'Umbundu',
        'ur' => 'Urdu',
        'uz' => 'Usbekisch',
        'vai' => 'Vai',
        've' => 'Venda',
        'vec' => 'Venetisch',
        'vep' => 'Wepsisch',
        'vi' => 'Vietnamesisch',
        'vls' => 'Westflämisch',
        'vmf' => 'Mainfränkisch',
        'vo' => 'Volapük',
        'vot' => 'Wotisch',
        'vro' => 'Võro',
        'vun' => 'Vunjo',
        'wa' => 'Wallonisch',
        'wae' => 'Walliserdeutsch',
        'wal' => 'Walamo',
        'war' => 'Waray',
        'was' => 'Washo',
        'wbp' => 'Warlpiri',
        'wo' => 'Wolof',
        'wuu' => 'Wu',
        'xal' => 'Kalmückisch',
        'xh' => 'Xhosa',
        'xmf' => 'Mingrelisch',
        'xog' => 'Soga',
        'yao' => 'Yao',
        'yap' => 'Yapesisch',
        'yav' => 'Yangben',
        'ybb' => 'Yemba',
        'yi' => 'Jiddisch',
        'yo' => 'Yoruba',
        'yrl' => 'Nheengatu',
        'yue' => 'Kantonesisch',
        'za' => 'Zhuang',
        'zap' => 'Zapotekisch',
        'zbl' => 'Bliss-Symbole',
        'zea' => 'Seeländisch',
        'zen' => 'Zenaga',
        'zgh' => 'Tamazight',
        'zh' => 'Chinesisch',
        'zu' => 'Zulu',
        'zun' => 'Zuni',
        'zza' => 'Zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'Modernes Hocharabisch',
        'de_AT' => 'Österreichisches Deutsch',
        'de_CH' => 'Schweizer Hochdeutsch',
        'fa_AF' => 'Dari',
        'nds_NL' => 'Niedersächsisch',
        'nl_BE' => 'Flämisch',
        'ro_MD' => 'Moldauisch',
        'sw_CD' => 'Kongo-Swahili',
        'zh_Hans' => 'Chinesisch (vereinfacht)',
        'zh_Hant' => 'Chinesisch (traditionell)',
    ],
];
